#
# spec file for package kjots
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kjots
Version:        5.1.0
Release:        bp155.3.6
Summary:        A note taking application using Akonadi
License:        GPL-2.0-only AND LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://userbase.kde.org/KJots/
Source0:        https://download.kde.org/stable/kjots/%{version}/src/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         noteshared-add-missing-library-to-link-list.patch
Patch1:         Adapt-to-new-Akonadi-libraries.patch
# PATCH-FIX-UPSTREAM
Patch2:         Fix-akonadi-includes.patch
Patch3:         Fix-build-with-Akonadi-21.12.patch
Patch4:         0001-Adapt-to-new-KontactInterface-Plugin-ctor.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Grantlee5)
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5AkonadiNotes)
BuildRequires:  cmake(KF5Bookmarks)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5KontactInterface)
BuildRequires:  cmake(KF5Libkdepim)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5PimTextEdit)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5PrintSupport)

%description
This package contains KJOTS, a note taking application using Akonadi.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf5 -d build

%make_jobs

%install
%kf5_makeinstall -C build
%suse_update_desktop_file -C "Note Taker" org.kde.kjots    Utility  DesktopUtility
%find_lang %{name}

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING COPYING.LIB
%doc ANNOUNCE CHANGES README
%{_kf5_appstreamdir}/
%{_kf5_applicationsdir}/org.kde.kjots.desktop
%{_kf5_bindir}/kjots
%{_kf5_configkcfgdir}/kjots.kcfg
%{_kf5_kxmlguidir}/kjots/
%{_kf5_servicesdir}/kjotspart.desktop
%{_kf5_plugindir}/kjotspart.so
%{_kf5_plugindir}/kcm_kjots.so
%{_kf5_servicesdir}/kjots_config_misc.desktop
%{_kf5_sharedir}/kjots/
%{_kf5_iconsdir}/hicolor/*/apps/kjots.*
%dir %{_kf5_plugindir}/kontact5/
%{_kf5_plugindir}/kontact5/kontact_kjotsplugin.so
%{_kf5_sharedir}/kontact/
%{_kf5_servicesdir}/kontact/

%files lang -f kjots.lang

%changelog
* Fri Aug 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with recent kontactinterface releases:
  * 0001-Adapt-to-new-KontactInterface-Plugin-ctor.patch
* Fri Apr  1 2022 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix build with Akonadi 22.04:
  * Fix-akonadi-includes.patch
  * Fix-build-with-Akonadi-21.12.patch
- Drop redundant recommendation of the -lang package
* Tue Nov 30 2021 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix build with Akonadi 21.12:
  * noteshared-add-missing-library-to-link-list.patch
  * Adapt-to-new-Akonadi-libraries.patch
* Tue Jun 29 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to version 5.1.0:
  * No changelog available
- Drop patches merged upstream:
  * Fix-bookmarks-actions.patch
  * Install-the-kontact-plugin-into-kontact5.patch
- Update build requirements
- Run spec-cleaner
- Update URL
- Remove "for KDE" from package summary and description
* Thu Jul 23 2020 wbauer@tmo.at
- Add Install-the-kontact-plugin-into-kontact5.patch to fix build
  with kontactinterface 20.08
* Mon Apr 20 2020 wbauer@tmo.at
- Add Fix-bookmarks-actions.patch to fix "Ambiguous shortcuts"
  warning and a possible crash on start (kde#384000)
* Mon Dec 19 2016 wbauer@tmo.at
- Update to version 5.0.2:
  * some bugfixes
  * new ability to include images in notes
- Drop included patches: fix-desktop-file.patch, fix-build.patch,
  fix-icons.diff, fix-appstream.diff, enable-image-insert.patch,
  add-kontact-plugin.diff
* Sat Sep 10 2016 tittiatcoke@gmail.com
- Add fix-appstream.diff patch from upstream instead of moving
  files around after build
- Add add-kontact-plugin.diff (bko#359380). Now Kjots also shows up
  in kontact
- Add enable-image-insert.patch from upstream so that images can be
  included in the created notes
- Add fix-icons.diff to fix build with newer Frameworks.
* Mon Aug  8 2016 wbauer@tmo.at
- Add fix-build.patch to fix build with KDE Applications 16.08
* Sun Jul 24 2016 wbauer@tmo.at
- Remove boost-devel build requirement, it's not needed
* Sat Jun 18 2016 asterios.dramis@gmail.com
- Update to version 5.0.1:
  * Make it compile with Applications/15.12.
  * Add COPYING files.
- Removed make-it-build.diff (fixed upstream).
* Thu May 12 2016 dimstar@opensuse.org
- Fix name of appdata.xml file and content to be aligned with the
  .desktop file that has been renamed.
- Add a comment to the .desktop file.
* Sun Feb 14 2016 tittiatcoke@gmail.com
- Add patch fix-desktop-file.patch to make the installed
  desktop file work again. Thanks to Christian Trippe to
  detect the error.
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Update license
* Wed Jan 27 2016 tittiatcoke@gmail.com
- Initial version 5.0.0
